#ifndef VIEWER_H
#define VIEWER_H

//A mettre pour raytracing gpu
#define USE_GPURT

//GPU RayTracer
#ifdef USE_GPURT
#include <GPURT.h>
#endif

#include <QGLViewer/qglviewer.h>
#include "rayTracer.h"
#include "ray.h"
#include "hit.h"


class Scene;

class Viewer : public QGLViewer
{
public:
	Viewer(){
#ifdef USE_GPURT
		gpuRT_=NULL;
#endif
		curManipulatedLight=0;

	}
  ~Viewer();
  
  void loadScene(const QString& name);

  const Scene* const scene() const { return scene_; };
  const RayTracer& rayTracer() const { return rayTracer_; }

  void setScene(Scene* const scene) { scene_ = scene; };
  void setRayTracer(const RayTracer& rayTracer) { rayTracer_ = rayTracer; }

protected :
  virtual void draw();
  virtual void init();
  virtual QString helpString() const;
  virtual void keyPressEvent(QKeyEvent *e);
  virtual void select(const QPoint& point);

  Scene* const scene() { return scene_; };

  void print(const char *txt, float val);

#ifdef USE_GPURT
  void initGPURT();
#endif

private:
  // Definit la position F1 comme tant celle de la camera.
  void initFromScene();

  Scene* scene_;
  RayTracer rayTracer_;

  Ray ray_;
  Hit rayhit_;

  int curManipulatedLight;

#ifdef USE_GPURT
  //GPURT
  GPURT *gpuRT_;
#endif

/*#ifdef USE_GPURT
public slots:
	void updateGPURT();
#endif*/
};

#endif // VIEWER_H
